@@ -42,6 +42,9 @@ import org.xml.sax.helpers.DefaultHandler;
 public class Driver implements Locator, XMLReader, Attributes
 {
 
+    protected static final String EXTERNAL_GENERAL_ENTITIES_PROPERTY =
+        "http://xml.org/sax/features/external-general-entities";
+
     protected static final String DECLARATION_HANDLER_PROPERTY =
         "http://xml.org/sax/properties/declaration-handler";
 
@@ -200,6 +203,8 @@ public class Driver implements Locator, XMLReader, Attributes
                 }
             } else if(VALIDATION_FEATURE.equals(name)) {
                 pp.setFeature(XmlPullParser.FEATURE_VALIDATION, value);
+            } else if(EXTERNAL_GENERAL_ENTITIES_PROPERTY.equals(name)) {
+                // ignore
             } else {
                 pp.setFeature(name, value);
                 //throw new SAXNotRecognizedException("unrecognized feature "+name);
@@ -352,7 +357,7 @@ public class Driver implements Locator, XMLReader, Attributes
                     "start tag must be read before skiping subtree"+pp.getPositionDescription());
             }
             final int[] holderForStartAndLength = new int[2];
-            final StringBuffer rawName = new StringBuffer(16);
+            final StringBuilder rawName = new StringBuilder(16);
             String prefix = null;
             String name = null;
             int level = pp.getDepth() - 1;
@@ -449,11 +454,15 @@ public class Driver implements Locator, XMLReader, Attributes
     }
 
     /**
-     * Calls {@link ContentHandler.startElement(String, String, String, Attributes) startElement}
+     * Calls {@link ContentHandler#startElement(String, String, String, Attributes) ContentHandler.startElement}
      * on the <code>ContentHandler</code> with <code>this</code> driver object as the
      * {@link Attributes} implementation. In default implementation
      * {@link Attributes} object is valid only during this method call and may not
      * be stored. Sub-classes can overwrite this method to cache attributes.
+     * @param namespace The namespace.
+     * @param localName The localname.
+     * @param qName The qName.
+     * @throws SAXException in case of an error.
      */
     protected void startElement(String namespace, String localName, String qName) throws SAXException {
         contentHandler.startElement(namespace, localName, qName, this);
